diff --git a/res/res_pjsip_t38.c b/res/res_pjsip_t38.c
index 11804e2c29..009dddcdec 100644
--- a/res/res_pjsip_t38.c
+++ b/res/res_pjsip_t38.c
@@ -322,6 +322,12 @@ static int t38_reinvite_response_cb(struct ast_sip_session *session, pjsip_rx_da
 		int index;
 
 		session_media = session->active_media_state->default_session[AST_MEDIA_TYPE_IMAGE];
+		if (!session_media) {
+			ast_log(LOG_WARNING, "Received %d response to T.38 re-invite on '%s' but no session media\n",
+					status.code, session->channel ? ast_channel_name(session->channel) : "unknown channel");
+			return 0;
+		}
+
 		t38_change_state(session, session_media, state, T38_ENABLED);
 
 		/* Stop all the streams in the stored away active state, they'll go back to being active once
@@ -336,7 +342,8 @@ static int t38_reinvite_response_cb(struct ast_sip_session *session, pjsip_rx_da
 		}
 	} else {
 		session_media = session->pending_media_state->default_session[AST_MEDIA_TYPE_IMAGE];
-		t38_change_state(session, session_media, state, T38_REJECTED);
+		/* If no session_media then response contained a declined stream, so disable */
+		t38_change_state(session, session_media, state, session_media ? T38_REJECTED : T38_DISABLED);
 
 		/* Abort this attempt at switching to T.38 by resetting the pending state and freeing our stored away active state */
 		ast_sip_session_media_state_free(state->media_state);
@@ -454,6 +461,10 @@ static int t38_interpret_parameters(void *obj)
 			state->our_parms.version = MIN(state->our_parms.version, state->their_parms.version);
 			state->our_parms.rate_management = state->their_parms.rate_management;
 			session_media = data->session->pending_media_state->default_session[AST_MEDIA_TYPE_IMAGE];
+			if (!session_media) {
+				ast_log(LOG_ERROR, "Failed peer reinvite - No pending session media.\n");
+				break;
+			}
 			ast_udptl_set_local_max_ifp(session_media->udptl, state->our_parms.max_ifp);
 			t38_change_state(data->session, session_media, state, T38_ENABLED);
 			ast_sip_session_resume_reinvite(data->session);
@@ -493,6 +504,10 @@ static int t38_interpret_parameters(void *obj)
 
 		if (data->session->t38state == T38_PEER_REINVITE) {
 			session_media = data->session->pending_media_state->default_session[AST_MEDIA_TYPE_IMAGE];
+			if (!session_media) {
+				ast_log(LOG_ERROR, "Failed request parameters - No pending session media.\n");
+				break;
+			}
 			parameters.max_ifp = ast_udptl_get_far_max_ifp(session_media->udptl);
 			parameters.request_response = AST_T38_REQUEST_NEGOTIATE;
 			ast_queue_control_data(data->session->channel, AST_CONTROL_T38_PARAMETERS, &parameters, sizeof(parameters));
